@@ -1,9 +1,9 @@
-import React, { useEffect, useState } from 'react';
+import { useEffect, useState } from 'react';
+import * as React from 'react';
 import { SkeletonTheme } from 'react-loading-skeleton';
 
-import { GrafanaTheme2 } from '@grafana/data';
+import { GrafanaTheme2, ThemeContext } from '@grafana/data';
 import { ThemeChangedEvent, config } from '@grafana/runtime';
-import { ThemeContext } from '@grafana/ui';
 
 import { appEvents } from '../core';
 
@@ -24,9 +24,9 @@ export const ThemeProvider = ({ children, value }: { children: React.ReactNode;
   return (
     <ThemeContext.Provider value={theme}>
       <SkeletonTheme
-        baseColor={theme.colors.background.secondary}
-        highlightColor={theme.colors.emphasize(theme.colors.background.secondary)}
-        borderRadius={theme.shape.borderRadius()}
+        baseColor={theme.colors.emphasize(theme.colors.background.secondary)}
+        highlightColor={theme.colors.emphasize(theme.colors.background.secondary, 0.1)}
+        borderRadius={theme.shape.radius.default}
       >
         {children}
       </SkeletonTheme>
@@ -34,8 +34,8 @@ export const ThemeProvider = ({ children, value }: { children: React.ReactNode;
   );
 };
 
-export const provideTheme = (component: React.ComponentType<any>, theme: GrafanaTheme2) => {
-  return function ThemeProviderWrapper(props: any) {
+export const provideTheme = <P extends {}>(component: React.ComponentType<P>, theme: GrafanaTheme2) => {
+  return function ThemeProviderWrapper(props: P) {
     return <ThemeProvider value={theme}>{React.createElement(component, { ...props })}</ThemeProvider>;
   };
 };
