@@ -3,7 +3,7 @@ import { useEffect, useState } from 'react';
 
 import { GrafanaTheme2 } from '@grafana/data';
 import { config, GrafanaBootConfig } from '@grafana/runtime';
-import { LinkButton, useStyles2 } from '@grafana/ui';
+import { LinkButton, Stack, useStyles2 } from '@grafana/ui';
 import { Trans } from 'app/core/internationalization';
 import { AccessControlAction } from 'app/types';
 
@@ -43,7 +43,13 @@ export const ServerStats = () => {
           <Trans i18nKey="admin.server-settings.not-found">No stats found.</Trans>
         </p>
       ) : (
-        <div className={styles.row}>
+        <Stack
+          gap={2}
+          direction={{
+            xs: 'column',
+            md: 'row',
+          }}
+        >
           <ServerStatsCard
             isLoading={isLoading}
             content={[
@@ -59,7 +65,7 @@ export const ServerStats = () => {
             }
           />
 
-          <div className={styles.doubleRow}>
+          <Stack direction="column" gap={2}>
             <ServerStatsCard
               isLoading={isLoading}
               content={[{ name: 'Data sources', value: stats?.datasources }]}
@@ -80,7 +86,7 @@ export const ServerStats = () => {
                 </LinkButton>
               }
             />
-          </div>
+          </Stack>
           <ServerStatsCard
             isLoading={isLoading}
             content={[
@@ -98,7 +104,7 @@ export const ServerStats = () => {
               )
             }
           />
-        </div>
+        </Stack>
       )}
     </>
   );
@@ -133,27 +139,6 @@ const getStyles = (theme: GrafanaTheme2) => {
     title: css({
       marginBottom: theme.spacing(4),
     }),
-    row: css({
-      display: 'flex',
-      justifyContent: 'space-between',
-      width: '100%',
-
-      '& > div:not(:last-of-type)': {
-        marginRight: theme.spacing(2),
-      },
-
-      '& > div': {
-        width: '33.3%',
-      },
-    }),
-    doubleRow: css({
-      display: 'flex',
-      flexDirection: 'column',
-
-      '& > div:first-of-type': {
-        marginBottom: theme.spacing(2),
-      },
-    }),
     notFound: css({
       fontSize: theme.typography.h6.fontSize,
       textAlign: 'center',
