@@ -1,8 +1,10 @@
-import React, { PureComponent } from 'react';
+import { createRef, PureComponent } from 'react';
 
 import { ConfirmButton, ConfirmModal, Button, Stack } from '@grafana/ui';
+import { TagBadge } from 'app/core/components/TagFilter/TagBadge';
 import { contextSrv } from 'app/core/core';
-import { i18nDate } from 'app/core/internationalization';
+import { t, Trans } from 'app/core/internationalization';
+import { formatDate } from 'app/core/internationalization/dates';
 import { AccessControlAction, UserSession } from 'app/types';
 
 interface Props {
@@ -17,7 +19,7 @@ interface State {
 }
 
 class BaseUserSessions extends PureComponent<Props, State> {
-  forceAllLogoutButton = React.createRef<HTMLButtonElement>();
+  forceAllLogoutButton = createRef<HTMLButtonElement>();
   state: State = {
     showLogoutModal: false,
   };
@@ -51,16 +53,29 @@ class BaseUserSessions extends PureComponent<Props, State> {
 
     return (
       <div>
-        <h3 className="page-heading">Sessions</h3>
+        <h3 className="page-heading">
+          <Trans i18nKey="admin.user-sessions.title">Sessions</Trans>
+        </h3>
         <Stack direction="column" gap={1.5}>
           <div>
             <table className="filter-table form-inline">
               <thead>
                 <tr>
-                  <th>Last seen</th>
-                  <th>Logged on</th>
-                  <th>IP address</th>
-                  <th colSpan={2}>Browser and OS</th>
+                  <th>
+                    <Trans i18nKey="admin.user-sessions.last-seen-column">Last seen</Trans>
+                  </th>
+                  <th>
+                    <Trans i18nKey="admin.user-sessions.logged-on-column">Logged on</Trans>
+                  </th>
+                  <th>
+                    <Trans i18nKey="admin.user-sessions.ip-column">IP address</Trans>
+                  </th>
+                  <th>
+                    <Trans i18nKey="admin.user-sessions.browser-column">Browser and OS</Trans>
+                  </th>
+                  <th colSpan={2}>
+                    <Trans i18nKey="user-session.auth-module-column">Identity Provider</Trans>
+                  </th>
                 </tr>
               </thead>
               <tbody>
@@ -68,22 +83,22 @@ class BaseUserSessions extends PureComponent<Props, State> {
                   sessions.map((session, index) => (
                     <tr key={`${session.id}-${index}`}>
                       <td>{session.isActive ? 'Now' : session.seenAt}</td>
-                      <td>{i18nDate(session.createdAt, { dateStyle: 'long' })}</td>
+                      <td>{formatDate(session.createdAt, { dateStyle: 'long' })}</td>
                       <td>{session.clientIp}</td>
                       <td>{`${session.browser} on ${session.os} ${session.osVersion}`}</td>
                       <td>
-                        <div className="pull-right">
-                          {canLogout && (
-                            <ConfirmButton
-                              confirmText="Confirm logout"
-                              confirmVariant="destructive"
-                              onConfirm={this.onSessionRevoke(session.id)}
-                              autoFocus
-                            >
-                              Force logout
-                            </ConfirmButton>
-                          )}
-                        </div>
+                        {session.authModule && <TagBadge label={session.authModule} removeIcon={false} count={0} />}
+                      </td>
+                      <td>
+                        {canLogout && (
+                          <ConfirmButton
+                            confirmText="Confirm logout"
+                            confirmVariant="destructive"
+                            onConfirm={this.onSessionRevoke(session.id)}
+                          >
+                            {t('admin.user-sessions.force-logout-button', 'Force logout')}
+                          </ConfirmButton>
+                        )}
                       </td>
                     </tr>
                   ))}
@@ -94,7 +109,7 @@ class BaseUserSessions extends PureComponent<Props, State> {
           <div>
             {canLogout && sessions.length > 0 && (
               <Button variant="secondary" onClick={this.showLogoutConfirmationModal} ref={this.forceAllLogoutButton}>
-                Force logout from all devices
+                <Trans i18nKey="admin.user-sessions.force-logout-all-button">Force logout from all devices</Trans>
               </Button>
             )}
             <ConfirmModal
