@@ -1,5 +1,3 @@
-import React from 'react';
-
 import { Badge } from '@grafana/ui';
 
 export const UnusedContactPointBadge = () => (
@@ -8,6 +6,6 @@ export const UnusedContactPointBadge = () => (
     aria-label="unused"
     color="orange"
     icon="exclamation-triangle"
-    tooltip="This contact point is not used in any notification policy and it will not receive any alerts"
+    tooltip="This contact point is not used in any notification policy or alert rule"
   />
 );
