@@ -1,50 +1,66 @@
-import React, { useCallback, useEffect, useMemo, useState } from 'react';
+import { memo, useCallback, useEffect, useMemo, useState } from 'react';
 import { FormProvider, useForm } from 'react-hook-form';
 import { useAsync } from 'react-use';
 
-import { Button, CustomScrollbar, LinkButton, LoadingPlaceholder, Stack } from '@grafana/ui';
+import { Button, LinkButton, LoadingPlaceholder, Stack } from '@grafana/ui';
 import { useAppNotification } from 'app/core/copy/appNotification';
-import { useQueryParams } from 'app/core/hooks/useQueryParams';
+import { Trans } from 'app/core/internationalization';
 
 import { AppChromeUpdate } from '../../../../../../core/components/AppChrome/AppChromeUpdate';
-import { RulerRuleDTO, RulerRuleGroupDTO } from '../../../../../../types/unified-alerting-dto';
-import { alertRuleApi, ModifyExportPayload } from '../../../api/alertRuleApi';
+import {
+  PostableRulerRuleGroupDTO,
+  RulerRuleDTO,
+  RulerRuleGroupDTO,
+} from '../../../../../../types/unified-alerting-dto';
+import { alertRuleApi } from '../../../api/alertRuleApi';
 import { fetchRulerRulesGroup } from '../../../api/ruler';
 import { useDataSourceFeatures } from '../../../hooks/useCombinedRule';
-import { RuleFormValues } from '../../../types/rule-form';
+import { useReturnTo } from '../../../hooks/useReturnTo';
+import { DEFAULT_GROUP_EVALUATION_INTERVAL, getDefaultFormValues } from '../../../rule-editor/formDefaults';
+import { RuleFormType, RuleFormValues } from '../../../types/rule-form';
 import { GRAFANA_RULES_SOURCE_NAME } from '../../../utils/datasource';
-import { formValuesToRulerGrafanaRuleDTO, MINUTE } from '../../../utils/rule-form';
-import { isGrafanaRulerRule } from '../../../utils/rules';
+import { formValuesToRulerGrafanaRuleDTO, getDefaultQueries } from '../../../utils/rule-form';
+import { rulerRuleType } from '../../../utils/rules';
 import { FileExportPreview } from '../../export/FileExportPreview';
 import { GrafanaExportDrawer } from '../../export/GrafanaExportDrawer';
-import { allGrafanaExportProviders, ExportFormats } from '../../export/providers';
-import { AlertRuleNameInput } from '../AlertRuleNameInput';
+import { ExportFormats, HclExportProvider, allGrafanaExportProviders } from '../../export/providers';
+import { AlertRuleNameAndMetric } from '../AlertRuleNameInput';
 import AnnotationsStep from '../AnnotationsStep';
-import { GrafanaEvaluationBehavior } from '../GrafanaEvaluationBehavior';
+import { GrafanaEvaluationBehaviorStep } from '../GrafanaEvaluationBehavior';
+import { GrafanaFolderAndLabelsStep } from '../GrafanaFolderAndLabelsStep';
 import { NotificationsStep } from '../NotificationsStep';
 import { QueryAndExpressionsStep } from '../query-and-alert-condition/QueryAndExpressionsStep';
 
 interface ModifyExportRuleFormProps {
-  alertUid: string;
+  alertUid?: string;
   ruleForm?: RuleFormValues;
 }
 
 export function ModifyExportRuleForm({ ruleForm, alertUid }: ModifyExportRuleFormProps) {
+  const defaultValuesForNewRule: RuleFormValues = useMemo(() => {
+    const defaultRuleType = RuleFormType.grafana;
+
+    return {
+      ...getDefaultFormValues(),
+      condition: 'C',
+      queries: getDefaultQueries(false),
+      type: defaultRuleType,
+      evaluateEvery: DEFAULT_GROUP_EVALUATION_INTERVAL,
+    };
+  }, []);
+
   const formAPI = useForm<RuleFormValues>({
     mode: 'onSubmit',
-    defaultValues: ruleForm,
+    defaultValues: ruleForm ?? defaultValuesForNewRule,
     shouldFocusError: true,
   });
-  const [queryParams] = useQueryParams();
 
-  const existing = Boolean(ruleForm); // always should be true
+  const existing = Boolean(ruleForm);
   const notifyApp = useAppNotification();
-  const returnTo = !queryParams['returnTo'] ? '/alerting/list' : String(queryParams['returnTo']);
+  const { returnTo } = useReturnTo('/alerting/list');
 
   const [exportData, setExportData] = useState<RuleFormValues | undefined>(undefined);
-
   const [conditionErrorMsg, setConditionErrorMsg] = useState('');
-  const [evaluateEvery, setEvaluateEvery] = useState(ruleForm?.evaluateEvery ?? MINUTE);
 
   const onInvalid = (): void => {
     notifyApp.error('There are errors in the form. Please correct them and try again!');
@@ -68,7 +84,7 @@ export function ModifyExportRuleForm({ ruleForm, alertUid }: ModifyExportRuleFor
 
   const actionButtons = [
     <LinkButton href={returnTo} key="cancel" size="sm" variant="secondary" onClick={() => submit(undefined)}>
-      Cancel
+      <Trans i18nKey="alerting.common.cancel">Cancel</Trans>
     </LinkButton>,
     <Button key="export-rule" size="sm" onClick={formAPI.handleSubmit((formValues) => submit(formValues), onInvalid)}>
       Export
@@ -81,28 +97,21 @@ export function ModifyExportRuleForm({ ruleForm, alertUid }: ModifyExportRuleFor
         <AppChromeUpdate actions={actionButtons} />
         <form onSubmit={(e) => e.preventDefault()}>
           <div>
-            <CustomScrollbar autoHeightMin="100%" hideHorizontalTrack={true}>
-              <Stack direction="column" gap={3}>
-                {/* Step 1 */}
-                <AlertRuleNameInput />
-                {/* Step 2 */}
-                <QueryAndExpressionsStep editingExistingRule={existing} onDataChange={checkAlertCondition} />
-                {/* Step 3-4-5 */}
+            <Stack direction="column" gap={3}>
+              {/* Step 1 */}
+              <AlertRuleNameAndMetric />
+              {/* Step 2 */}
+              <QueryAndExpressionsStep editingExistingRule={existing} onDataChange={checkAlertCondition} />
+              {/* Step 3-4-5 */}
+              <GrafanaFolderAndLabelsStep />
 
-                <GrafanaEvaluationBehavior
-                  evaluateEvery={evaluateEvery}
-                  setEvaluateEvery={setEvaluateEvery}
-                  existing={Boolean(existing)}
-                  enableProvisionedGroups={true}
-                />
-
-                {/* Step 4 & 5 */}
-                {/* Notifications step*/}
-                <NotificationsStep alertUid={alertUid} />
-                {/* Annotations only for cloud and Grafana */}
-                <AnnotationsStep />
-              </Stack>
-            </CustomScrollbar>
+              {/* Step 4 & 5 */}
+              <GrafanaEvaluationBehaviorStep existing={Boolean(existing)} enableProvisionedGroups={true} />
+              {/* Notifications step*/}
+              <NotificationsStep alertUid={alertUid} />
+              {/* Annotations only for cloud and Grafana */}
+              <AnnotationsStep />
+            </Stack>
           </div>
         </form>
         {exportData && <GrafanaRuleDesignExporter exportValues={exportData} onClose={onClose} uid={alertUid} />}
@@ -127,21 +136,21 @@ interface GrafanaRuleDesignExportPreviewProps {
   exportFormat: ExportFormats;
   onClose: () => void;
   exportValues: RuleFormValues;
-  uid: string;
+  uid?: string;
 }
 export const getPayloadToExport = (
-  uid: string,
   formValues: RuleFormValues,
-  existingGroup: RulerRuleGroupDTO<RulerRuleDTO> | null | undefined
-): ModifyExportPayload => {
+  existingGroup: RulerRuleGroupDTO<RulerRuleDTO> | null | undefined,
+  ruleUid?: string
+): PostableRulerRuleGroupDTO => {
   const grafanaRuleDto = formValuesToRulerGrafanaRuleDTO(formValues);
 
-  const updatedRule = { ...grafanaRuleDto, grafana_alert: { ...grafanaRuleDto.grafana_alert, uid: uid } };
+  const updatedRule = { ...grafanaRuleDto, grafana_alert: { ...grafanaRuleDto.grafana_alert, uid: ruleUid } };
   if (existingGroup?.rules) {
     // we have to update the rule in the group in the same position if it exists, otherwise we have to add it at the end
     let alreadyExistsInGroup = false;
     const updatedRules = existingGroup.rules.map((rule: RulerRuleDTO) => {
-      if (isGrafanaRulerRule(rule) && rule.grafana_alert.uid === uid) {
+      if (rulerRuleType.grafana.rule(rule) && rule.grafana_alert.uid === ruleUid) {
         alreadyExistsInGroup = true;
         return updatedRule;
       } else {
@@ -159,17 +168,17 @@ export const getPayloadToExport = (
   } else {
     // we have to create a new group with the updated rule
     return {
-      name: existingGroup?.name ?? '',
+      name: existingGroup?.name ?? formValues.group,
       rules: [updatedRule],
     };
   }
 };
 
-const useGetPayloadToExport = (values: RuleFormValues, uid: string) => {
+const useGetPayloadToExport = (values: RuleFormValues, ruleUid?: string) => {
   const rulerGroupDto = useGetGroup(values.folder?.uid ?? '', values.group);
-  const payload: ModifyExportPayload = useMemo(() => {
-    return getPayloadToExport(uid, values, rulerGroupDto?.value);
-  }, [uid, rulerGroupDto, values]);
+  const payload: PostableRulerRuleGroupDTO = useMemo(() => {
+    return getPayloadToExport(values, rulerGroupDto?.value, ruleUid);
+  }, [ruleUid, rulerGroupDto, values]);
   return { payload, loadingGroup: rulerGroupDto.loading };
 };
 
@@ -185,7 +194,7 @@ const GrafanaRuleDesignExportPreview = ({
   const nameSpaceUID = exportValues.folder?.uid ?? '';
 
   useEffect(() => {
-    !loadingGroup && getExport({ payload, format: exportFormat, nameSpaceUID });
+    !loadingGroup && payload.name && getExport({ payload, format: exportFormat, nameSpaceUID });
   }, [nameSpaceUID, exportFormat, payload, getExport, loadingGroup]);
 
   if (exportData.isLoading) {
@@ -207,30 +216,31 @@ const GrafanaRuleDesignExportPreview = ({
 interface GrafanaRuleDesignExporterProps {
   onClose: () => void;
   exportValues: RuleFormValues;
-  uid: string;
+  uid?: string;
 }
 
-export const GrafanaRuleDesignExporter = React.memo(
-  ({ onClose, exportValues, uid }: GrafanaRuleDesignExporterProps) => {
-    const [activeTab, setActiveTab] = useState<ExportFormats>('yaml');
+export const GrafanaRuleDesignExporter = memo(({ onClose, exportValues, uid }: GrafanaRuleDesignExporterProps) => {
+  const exportingNewRule = !uid;
+  const initialTab = exportingNewRule ? 'hcl' : 'yaml';
+  const [activeTab, setActiveTab] = useState<ExportFormats>(initialTab);
+  const formatProviders = exportingNewRule ? [HclExportProvider] : Object.values(allGrafanaExportProviders);
 
-    return (
-      <GrafanaExportDrawer
-        title={'Export Group'}
-        activeTab={activeTab}
-        onTabChange={setActiveTab}
+  return (
+    <GrafanaExportDrawer
+      title={'Export Group'}
+      activeTab={activeTab}
+      onTabChange={setActiveTab}
+      onClose={onClose}
+      formatProviders={formatProviders}
+    >
+      <GrafanaRuleDesignExportPreview
+        exportFormat={activeTab}
         onClose={onClose}
-        formatProviders={Object.values(allGrafanaExportProviders)}
-      >
-        <GrafanaRuleDesignExportPreview
-          exportFormat={activeTab}
-          onClose={onClose}
-          exportValues={exportValues}
-          uid={uid}
-        />
-      </GrafanaExportDrawer>
-    );
-  }
-);
+        exportValues={exportValues}
+        uid={uid}
+      />
+    </GrafanaExportDrawer>
+  );
+});
 
 GrafanaRuleDesignExporter.displayName = 'GrafanaRuleDesignExporter';
