@@ -1,13 +1,14 @@
-import React from 'react';
+import { ComponentProps } from 'react';
 
-import { IconName, Tooltip, LinkButton, Button } from '@grafana/ui';
-import { PopoverContent, TooltipPlacement } from '@grafana/ui/src/components/Tooltip';
+import { Button, IconName, LinkButton, Tooltip } from '@grafana/ui';
+
+type TooltipProps = ComponentProps<typeof Tooltip>;
 
 interface Props {
-  tooltip: PopoverContent;
+  tooltip: TooltipProps['content'];
   icon: IconName;
   className?: string;
-  tooltipPlacement?: TooltipPlacement;
+  tooltipPlacement?: TooltipProps['placement'];
   to?: string;
   target?: string;
   onClick?: () => void;
