@@ -1,8 +1,10 @@
+import { produce } from 'immer';
 import { HttpResponse, delay, http } from 'msw';
 
 export const MOCK_GRAFANA_ALERT_RULE_TITLE = 'Test alert';
 
 import {
+  GrafanaRuleDefinition,
   PromRulesResponse,
   RulerGrafanaRuleDTO,
   RulerRuleGroupDTO,
@@ -90,6 +92,11 @@ export const rulerRuleGroupHandler = (options?: HandlerOptions) => {
       }
 
       const matchingGroup = namespace.find((group) => group.name === groupName);
+
+      if (!matchingGroup) {
+        return HttpResponse.json({ message: 'group does not exist' }, { status: 404 });
+      }
+
       return HttpResponse.json<RulerRuleGroupDTO>({
         name: groupName,
         interval: matchingGroup?.interval,
@@ -135,6 +142,64 @@ export const rulerRuleHandler = () => {
   });
 };
 
+export const rulerRuleVersionHistoryHandler = () => {
+  const grafanaRuleVersions = [
+    produce(grafanaRulerRule, (draft: RulerGrafanaRuleDTO<GrafanaRuleDefinition>) => {
+      draft.grafana_alert.version = 6;
+      draft.grafana_alert.updated = '2025-01-18T09:35:17.000Z';
+      draft.grafana_alert.updated_by = {
+        uid: 'service',
+        name: '',
+      };
+    }),
+    produce(grafanaRulerRule, (draft: RulerGrafanaRuleDTO<GrafanaRuleDefinition>) => {
+      draft.grafana_alert.version = 5;
+      draft.grafana_alert.updated = '2025-01-17T09:35:17.000Z';
+      draft.grafana_alert.updated_by = {
+        uid: '__alerting__',
+        name: '',
+      };
+    }),
+    produce(grafanaRulerRule, (draft: RulerGrafanaRuleDTO<GrafanaRuleDefinition>) => {
+      draft.grafana_alert.version = 4;
+      draft.grafana_alert.title = 'Some new title';
+      draft.grafana_alert.updated = '2025-01-16T09:35:17.000Z';
+      draft.grafana_alert.updated_by = {
+        uid: 'different',
+        name: 'different user',
+      };
+    }),
+    produce(grafanaRulerRule, (draft: RulerGrafanaRuleDTO<GrafanaRuleDefinition>) => {
+      draft.grafana_alert.version = 3;
+      draft.grafana_alert.updated = '2025-01-15T09:35:17.000Z';
+      draft.grafana_alert.updated_by = {
+        uid: '1',
+        name: 'user1',
+      };
+    }),
+    produce(grafanaRulerRule, (draft: RulerGrafanaRuleDTO<GrafanaRuleDefinition>) => {
+      draft.grafana_alert.version = 2;
+      draft.grafana_alert.updated = '2025-01-14T09:35:17.000Z';
+      draft.for = '2h';
+      draft.labels.foo = 'bar';
+      draft.grafana_alert.notification_settings = { receiver: 'another receiver' };
+      draft.grafana_alert.updated_by = {
+        uid: 'foo',
+        name: '',
+      };
+    }),
+    produce(grafanaRulerRule, (draft: RulerGrafanaRuleDTO<GrafanaRuleDefinition>) => {
+      draft.grafana_alert.version = 1;
+      draft.grafana_alert.updated = '2025-01-13T09:35:17.000Z';
+      draft.grafana_alert.updated_by = null;
+    }),
+  ];
+
+  return http.get<{ uid: string }>(`/api/ruler/grafana/api/v1/rule/:uid/versions`, ({ params: { uid } }) => {
+    return HttpResponse.json(grafanaRuleVersions);
+  });
+};
+
 export const historyHandler = () => {
   return http.get('/api/v1/rules/history', () => {
     return HttpResponse.json(getHistoryResponse([time_0, time_0, time_plus_30, time_plus_30]));
@@ -150,5 +215,6 @@ const handlers = [
   historyHandler(),
   updateRulerRuleNamespaceHandler(),
   deleteRulerRuleGroupHandler(),
+  rulerRuleVersionHistoryHandler(),
 ];
 export default handlers;
