@@ -1,19 +1,20 @@
-import React, { useEffect } from 'react';
+import { useEffect } from 'react';
 
 import { reportInteraction } from '@grafana/runtime/src';
 import { Trans } from 'app/core/internationalization';
 import { AddLibraryPanelContents } from 'app/features/library-panels/components/AddLibraryPanelModal/AddLibraryPanelModal';
 
 import { ShareModalTabProps } from './types';
+import { getTrackingSource } from './utils';
 
 interface Props extends ShareModalTabProps {
   initialFolderUid?: string;
 }
 
-export const ShareLibraryPanel = ({ panel, initialFolderUid, onDismiss }: Props) => {
+export const ShareLibraryPanel = ({ panel, initialFolderUid, onCreateLibraryPanel, onDismiss }: Props) => {
   useEffect(() => {
-    reportInteraction('grafana_dashboards_library_panel_share_viewed');
-  }, []);
+    reportInteraction('grafana_dashboards_library_panel_share_viewed', { shareResource: getTrackingSource(panel) });
+  }, [panel]);
 
   if (!panel) {
     return null;
@@ -21,10 +22,15 @@ export const ShareLibraryPanel = ({ panel, initialFolderUid, onDismiss }: Props)
 
   return (
     <>
-      <p className="share-modal-info-text">
+      <p>
         <Trans i18nKey="share-modal.library.info">Create library panel.</Trans>
       </p>
-      <AddLibraryPanelContents panel={panel} initialFolderUid={initialFolderUid} onDismiss={onDismiss!} />
+      <AddLibraryPanelContents
+        panel={panel}
+        initialFolderUid={initialFolderUid}
+        onCreateLibraryPanel={onCreateLibraryPanel}
+        onDismiss={onDismiss}
+      />
     </>
   );
 };
