@@ -1,9 +1,7 @@
 import { act, fireEvent, render, screen } from '@testing-library/react';
-import React from 'react';
 
 import { locationService, reportInteraction } from '@grafana/runtime';
 import { defaultDashboard } from '@grafana/schema';
-import config from 'app/core/config';
 
 import { createDashboardModelFixture } from '../state/__fixtures__/dashboardFixtures';
 import { onCreateNewPanel, onImportDashboard, onAddLibraryPanel } from '../utils/dashboard';
@@ -22,7 +20,6 @@ jest.mock('@grafana/runtime', () => ({
     partial: jest.fn(),
   },
   reportInteraction: jest.fn(),
-  config: {},
 }));
 
 jest.mock('app/features/dashboard/utils/dashboard', () => ({
@@ -42,7 +39,6 @@ function setup(options?: Partial<Props>) {
 }
 
 beforeEach(() => {
-  config.featureToggles = { vizAndWidgetSplit: false };
   jest.clearAllMocks();
 });
 
@@ -77,6 +73,7 @@ it('creates new visualization when clicked Add visualization', () => {
 
   expect(reportInteraction).toHaveBeenCalledWith('dashboards_emptydashboard_clicked', { item: 'add_visualization' });
   expect(locationService.partial).toHaveBeenCalled();
+  expect(locationService.partial).toHaveBeenCalledWith({ editPanel: undefined, firstPanel: true });
   expect(onCreateNewPanel).toHaveBeenCalled();
 });
 
@@ -111,13 +108,3 @@ it('renders page without Add Widget button when feature flag is disabled', () =>
   expect(screen.getByRole('button', { name: 'Add library panel' })).toBeInTheDocument();
   expect(screen.queryByRole('button', { name: 'Add widget' })).not.toBeInTheDocument();
 });
-
-it('renders page with Add Widget button when feature flag is enabled', () => {
-  config.featureToggles.vizAndWidgetSplit = true;
-  setup();
-
-  expect(screen.getByRole('button', { name: 'Add visualization' })).toBeInTheDocument();
-  expect(screen.getByRole('button', { name: 'Import dashboard' })).toBeInTheDocument();
-  expect(screen.getByRole('button', { name: 'Add library panel' })).toBeInTheDocument();
-  expect(screen.getByRole('button', { name: 'Add widget' })).toBeInTheDocument();
-});
