@@ -1,30 +1,30 @@
-import { identity } from 'lodash';
-import React, { useEffect, useMemo, useState } from 'react';
-import { usePrevious } from 'react-use';
+import { identity, isEqual, sortBy } from 'lodash';
+import { useEffect, useMemo, useRef, useState } from 'react';
+import * as React from 'react';
 
 import {
   AbsoluteTimeRange,
   applyFieldOverrides,
   createFieldConfigRegistry,
+  DashboardCursorSync,
   DataFrame,
-  dateTime,
+  EventBus,
   FieldColorModeId,
   FieldConfigSource,
   getFrameDisplayName,
   LoadingState,
   SplitOpen,
   ThresholdsConfig,
-  DashboardCursorSync,
-  EventBus,
+  TimeRange,
 } from '@grafana/data';
 import { PanelRenderer } from '@grafana/runtime';
 import {
   GraphDrawStyle,
-  LegendDisplayMode,
-  TooltipDisplayMode,
-  SortOrder,
   GraphThresholdsStyleConfig,
+  LegendDisplayMode,
+  SortOrder,
   TimeZone,
+  TooltipDisplayMode,
   VizLegendOptions,
 } from '@grafana/schema';
 import { PanelContext, PanelContextProvider, SeriesVisibilityChangeMode, useTheme2 } from '@grafana/ui';
@@ -43,7 +43,7 @@ interface Props {
   data: DataFrame[];
   height: number;
   width: number;
-  absoluteRange: AbsoluteTimeRange;
+  timeRange: TimeRange;
   timeZone: TimeZone;
   loadingState: LoadingState;
   annotations?: DataFrame[];
@@ -58,6 +58,7 @@ interface Props {
   thresholdsStyle?: GraphThresholdsStyleConfig;
   eventBus: EventBus;
   vizLegendOverrides?: Partial<VizLegendOptions>;
+  toggleLegendRef?: React.MutableRefObject<(name: string, mode: SeriesVisibilityChangeMode) => void>;
 }
 
 export function ExploreGraph({
@@ -65,7 +66,7 @@ export function ExploreGraph({
   height,
   width,
   timeZone,
-  absoluteRange,
+  timeRange,
   onChangeTime,
   loadingState,
   annotations,
@@ -79,21 +80,9 @@ export function ExploreGraph({
   thresholdsStyle,
   eventBus,
   vizLegendOverrides,
+  toggleLegendRef,
 }: Props) {
   const theme = useTheme2();
-  const previousTimeRange = usePrevious(absoluteRange);
-  const baseTimeRange = loadingState === LoadingState.Loading && previousTimeRange ? previousTimeRange : absoluteRange;
-  const timeRange = useMemo(
-    () => ({
-      from: dateTime(baseTimeRange.from),
-      to: dateTime(baseTimeRange.to),
-      raw: {
-        from: dateTime(baseTimeRange.from),
-        to: dateTime(baseTimeRange.to),
-      },
-    }),
-    [baseTimeRange.from, baseTimeRange.to]
-  );
 
   const fieldConfigRegistry = useMemo(
     () => createFieldConfigRegistry(getGraphFieldConfig(defaultGraphConfig), 'Explore'),
@@ -152,8 +141,11 @@ export function ExploreGraph({
 
   const structureRev = useStructureRev(dataWithConfig);
 
+  const onHiddenSeriesChangedRef = useRef(onHiddenSeriesChanged);
+  const previousHiddenFrames = useRef<string[] | undefined>(undefined);
+
   useEffect(() => {
-    if (onHiddenSeriesChanged) {
+    if (onHiddenSeriesChangedRef.current) {
       const hiddenFrames: string[] = [];
       dataWithConfig.forEach((frame) => {
         const allFieldsHidden = frame.fields.map((field) => field.config?.custom?.hideFrom?.viz).every(identity);
@@ -161,9 +153,15 @@ export function ExploreGraph({
           hiddenFrames.push(getFrameDisplayName(frame));
         }
       });
-      onHiddenSeriesChanged(hiddenFrames);
+      if (
+        previousHiddenFrames.current === undefined ||
+        !isEqual(sortBy(hiddenFrames), sortBy(previousHiddenFrames.current))
+      ) {
+        previousHiddenFrames.current = hiddenFrames;
+        onHiddenSeriesChangedRef.current(hiddenFrames);
+      }
     }
-  }, [dataWithConfig, onHiddenSeriesChanged]);
+  }, [dataWithConfig]);
 
   const panelContext: PanelContext = {
     eventsScope: 'explore',
@@ -176,6 +174,14 @@ export function ExploreGraph({
     dataLinkPostProcessor,
   };
 
+  function toggleLegend(name: string, mode: SeriesVisibilityChangeMode) {
+    setFieldConfig(seriesVisibilityConfigFactory(name, mode, fieldConfig, data));
+  }
+
+  if (toggleLegendRef) {
+    toggleLegendRef.current = toggleLegend;
+  }
+
   const panelOptions: TimeSeriesOptions = useMemo(
     () => ({
       tooltip: { mode: tooltipDisplayMode, sort: SortOrder.None },
