@@ -14,7 +14,6 @@
 
 import { css } from '@emotion/css';
 import cx from 'classnames';
-import * as React from 'react';
 
 import { GrafanaTheme2 } from '@grafana/data';
 import { useStyles2 } from '@grafana/ui';
@@ -26,10 +25,10 @@ import BreakableText from './BreakableText';
 
 const getStyles = (theme: GrafanaTheme2) => {
   return {
-    TraceName: css`
-      label: TraceName;
-      font-size: ${theme.typography.size.lg};
-    `,
+    TraceName: css({
+      label: 'TraceName',
+      fontSize: theme.typography.size.lg,
+    }),
   };
 };
 
