@@ -12,16 +12,8 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-export {
-  TraceSpan,
-  TraceResponse,
-  Trace,
-  TraceProcess,
-  TraceKeyValuePair,
-  TraceLink,
-  CriticalPathSection,
-} from './trace';
-export { SpanBarOptions, SpanBarOptionsData } from '../settings/SpanBarSettings';
-export { default as TTraceTimeline } from './TTraceTimeline';
-export { default as TNil } from './TNil';
-export { SpanLinkFunc, SpanLinkDef } from './links';
+export type { TraceSpan, TraceResponse, Trace, TraceProcess, TraceLink, CriticalPathSection } from './trace';
+export type { SpanBarOptions, SpanBarOptionsData } from '../settings/SpanBarSettings';
+export type { default as TTraceTimeline } from './TTraceTimeline';
+export type { default as TNil } from './TNil';
+export type { SpanLinkFunc, SpanLinkDef } from './links';
