@@ -1,6 +1,5 @@
-import React from 'react';
-
-import { Input, Field, FieldSet, Button, Form } from '@grafana/ui';
+import { Input, Field, FieldSet, Button } from '@grafana/ui';
+import { Form } from 'app/core/components/Form/Form';
 import { contextSrv } from 'app/core/core';
 import { AccessControlAction } from 'app/types';
 
