@@ -2,13 +2,10 @@ import { css } from '@emotion/css';
 import { useState } from 'react';
 
 import { GrafanaTheme2 } from '@grafana/data';
-import { config } from '@grafana/runtime';
 import { Icon, Stack, useStyles2 } from '@grafana/ui';
-import configCore from 'app/core/config';
 
 import { GetStartedWithPlugin } from '../components/GetStartedWithPlugin';
 import { InstallControlsButton } from '../components/InstallControls';
-import { ExternallyManagedButton } from '../components/InstallControls/ExternallyManagedButton';
 import { getLatestCompatibleVersion, hasInstallControlWarning, isInstallControlsEnabled } from '../helpers';
 import { useIsRemotePluginsAvailable } from '../state/hooks';
 import { CatalogPlugin, PluginStatus } from '../types';
@@ -28,7 +25,6 @@ export const PluginActions = ({ plugin }: Props) => {
   }
 
   const hasInstallWarning = hasInstallControlWarning(plugin, isRemotePluginsAvailable, latestCompatibleVersion);
-  const isExternallyManaged = config.pluginAdminExternalManageEnabled;
   const pluginStatus = plugin.isInstalled
     ? plugin.hasUpdate
       ? PluginStatus.UPDATE
@@ -41,23 +37,13 @@ export const PluginActions = ({ plugin }: Props) => {
     <Stack direction="column">
       <Stack alignItems="center">
         {!isInstallControlsDisabled && (
-          <>
-            {isExternallyManaged && !hasInstallWarning && !configCore.featureToggles.managedPluginsInstall ? (
-              <ExternallyManagedButton
-                pluginId={plugin.id}
-                pluginStatus={pluginStatus}
-                angularDetected={plugin.angularDetected}
-              />
-            ) : (
-              <InstallControlsButton
-                plugin={plugin}
-                latestCompatibleVersion={latestCompatibleVersion}
-                pluginStatus={pluginStatus}
-                setNeedReload={setNeedReload}
-                hasInstallWarning={hasInstallWarning}
-              />
-            )}
-          </>
+          <InstallControlsButton
+            plugin={plugin}
+            latestCompatibleVersion={latestCompatibleVersion}
+            pluginStatus={pluginStatus}
+            setNeedReload={setNeedReload}
+            hasInstallWarning={hasInstallWarning}
+          />
         )}
         <GetStartedWithPlugin plugin={plugin} />
       </Stack>
