@@ -30,7 +30,11 @@ export async function addDataTrailPanelAction(dashboard: DashboardScene, panel:
     return;
   }
 
-  if (datasource.type !== 'prometheus') {
+  if (
+    datasource.type !== 'prometheus' &&
+    datasource.type !== 'grafana-amazonprometheus-datasource' &&
+    datasource.type !== 'grafana-azureprometheus-datasource'
+  ) {
     return;
   }
 
