@@ -2,6 +2,8 @@ import { ComponentType } from 'react';
 import { Observable } from 'rxjs';
 
 import {
+  AdHocVariableModel,
+  ConstantVariableModel,
   DataQuery,
   DataQueryRequest,
   DataQueryResponse,
@@ -9,21 +11,16 @@ import {
   DataSourceJsonData,
   DataSourceRef,
   MetricFindValue,
+  QueryVariableModel,
   StandardVariableQuery,
   VariableModel,
   VariableSupportType,
+  VariableWithMultiSupport,
+  VariableWithOptions,
 } from '@grafana/data';
 
 import { LEGACY_VARIABLE_QUERY_EDITOR_NAME } from './editor/LegacyVariableQueryEditor';
-import {
-  AdHocVariableModel,
-  ConstantVariableModel,
-  QueryVariableModel,
-  VariableQueryEditorType,
-  VariableQueryEditorProps,
-  VariableWithMultiSupport,
-  VariableWithOptions,
-} from './types';
+import { VariableQueryEditorType, VariableQueryEditorProps } from './types';
 
 /** @deprecated use a if (model.type === "query") type narrowing check instead */
 export const isQuery = (model: VariableModel): model is QueryVariableModel => {
