@@ -1,26 +1,17 @@
-import React, { FC, useMemo } from 'react';
-import { Provider } from 'react-redux';
+import { useMemo } from 'react';
 
+import { TypedVariableModel } from '@grafana/data';
 import { reportInteraction } from '@grafana/runtime';
 import { Button } from '@grafana/ui';
 
-import { store } from '../../../store/store';
-import { VariableModel } from '../types';
-
 import { NetworkGraphModal } from './NetworkGraphModal';
 import { createDependencyEdges, createDependencyNodes, filterNodesWithDependencies } from './utils';
 
-interface OwnProps {
-  variables: VariableModel[];
+interface Props {
+  variables: TypedVariableModel[];
 }
 
-interface ConnectedProps {}
-
-interface DispatchProps {}
-
-type Props = OwnProps & ConnectedProps & DispatchProps;
-
-export const UnProvidedVariablesDependenciesButton: FC<Props> = ({ variables }) => {
+export const VariablesDependenciesButton = ({ variables }: Props) => {
   const nodes = useMemo(() => createDependencyNodes(variables), [variables]);
   const edges = useMemo(() => createDependencyEdges(variables), [variables]);
 
@@ -52,9 +43,3 @@ export const UnProvidedVariablesDependenciesButton: FC<Props> = ({ variables })
     </NetworkGraphModal>
   );
 };
-
-export const VariablesDependenciesButton: FC<Props> = (props) => (
-  <Provider store={store}>
-    <UnProvidedVariablesDependenciesButton {...props} />
-  </Provider>
-);
