@@ -1,12 +1,24 @@
 import { get, set } from 'lodash';
 
+import { ScopedVars } from '@grafana/data';
+import { VariableInterpolation } from '@grafana/runtime';
+
 import createMockQuery from '../__mocks__/query';
 import { createTemplateVariables } from '../__mocks__/utils';
 import { multiVariable } from '../__mocks__/variables';
 import AzureMonitorDatasource from '../datasource';
-import { AzureAPIResponse, AzureMonitorDataSourceInstanceSettings, Location } from '../types';
+import {
+  AzureAPIResponse,
+  AzureMonitorDataSourceInstanceSettings,
+  Location,
+  RawAzureResourceGroupItem,
+  RawAzureResourceItem,
+} from '../types';
 
-let replace = () => '';
+// We want replace to just return the value as is in general/
+// We declare this as a function so that we can overwrite it in each test
+// without affecting the rest of the @grafana/runtime module.
+let replace = (val: string) => val;
 
 jest.mock('@grafana/runtime', () => {
   return {
@@ -135,11 +147,22 @@ describe('AzureMonitorDatasource', () => {
     it('expand template variables in resource groups and names', () => {
       const resourceGroup = '$rg';
       const resourceName = '$rn';
-      replace = (target?: string) => {
+      replace = (
+        target?: string,
+        _scopedVars?: ScopedVars,
+        _format?: string | Function,
+        interpolated?: VariableInterpolation[]
+      ) => {
         if (target?.includes('$rg')) {
+          if (interpolated) {
+            interpolated.push({ value: 'rg1,rg2', match: '$rg', variableName: 'rg' });
+          }
           return 'rg1,rg2';
         }
         if (target?.includes('$rn')) {
+          if (interpolated) {
+            interpolated.push({ value: 'rn1,rn2', match: '$rn', variableName: 'rn' });
+          }
           return 'rn1,rn2';
         }
         return target || '';
@@ -163,6 +186,48 @@ describe('AzureMonitorDatasource', () => {
       });
     });
 
+    it('expand template variables in more complex resource groups and names', () => {
+      const resourceGroup = 'test-$rg-testGroup';
+      const resourceName = 'test-$rn-testResource';
+      replace = (
+        target?: string,
+        _scopedVars?: ScopedVars,
+        _format?: string | Function,
+        interpolated?: VariableInterpolation[]
+      ) => {
+        if (target?.includes('$rg')) {
+          if (interpolated) {
+            interpolated.push({ value: 'rg1,rg2', match: '$rg', variableName: 'rg' });
+          }
+          return 'rg1,rg2';
+        }
+        if (target?.includes('$rn')) {
+          if (interpolated) {
+            interpolated.push({ value: 'rn1,rn2', match: '$rn', variableName: 'rn' });
+          }
+          return 'rn1,rn2';
+        }
+        return target || '';
+      };
+      ctx.ds = new AzureMonitorDatasource(ctx.instanceSettings);
+      const query = createMockQuery({
+        azureMonitor: {
+          resources: [{ resourceGroup, resourceName }],
+        },
+      });
+      const templatedQuery = ctx.ds.azureMonitorDatasource.applyTemplateVariables(query, {});
+      expect(templatedQuery).toMatchObject({
+        azureMonitor: {
+          resources: [
+            { resourceGroup: 'test-rg1-testGroup', resourceName: 'test-rn1-testResource' },
+            { resourceGroup: 'test-rg2-testGroup', resourceName: 'test-rn1-testResource' },
+            { resourceGroup: 'test-rg1-testGroup', resourceName: 'test-rn2-testResource' },
+            { resourceGroup: 'test-rg2-testGroup', resourceName: 'test-rn2-testResource' },
+          ],
+        },
+      });
+    });
+
     it('expand template variables for a region', () => {
       const region = '$reg';
       replace = (target?: string) => {
@@ -251,8 +316,8 @@ describe('AzureMonitorDatasource', () => {
         const basePath = 'azuremonitor/subscriptions/mock-subscription-id/resourceGroups/nodeapp';
         const expected =
           basePath +
-          '/providers/microsoft.insights/components/resource1' +
-          '/providers/microsoft.insights/metricNamespaces?api-version=2017-12-01-preview&region=global';
+          '/providers/microsoft.insights/components/resource1/providers/microsoft.insights/metricNamespaces?api-version=2017-12-01-preview' +
+          (path.includes('&region=global') ? '&region=global' : '');
         expect(path).toBe(expected);
         return Promise.resolve(response);
       });
@@ -295,6 +360,24 @@ describe('AzureMonitorDatasource', () => {
           );
         });
     });
+
+    it('when custom is specified will only return custom namespaces', () => {
+      return ctx.ds.azureMonitorDatasource
+        .getMetricNamespaces(
+          {
+            resourceUri:
+              '/subscriptions/mock-subscription-id/resourceGroups/nodeapp/providers/microsoft.insights/components/resource1',
+          },
+          false,
+          undefined,
+          true
+        )
+        .then((results: Array<{ text: string; value: string }>) => {
+          expect(results.length).toEqual(1);
+          expect(results[0].text).toEqual('Azure.ApplicationInsights');
+          expect(results[0].value).toEqual('Azure.ApplicationInsights');
+        });
+    });
   });
 
   describe('When performing getMetricNames', () => {
@@ -677,20 +760,20 @@ describe('AzureMonitorDatasource', () => {
 
     describe('When performing getResourceGroups', () => {
       const response = {
-        value: [{ name: 'grp1' }, { name: 'grp2' }],
+        data: [{ resourceGroupName: 'grp1' }, { resourceGroupName: 'grp2' }],
       };
 
       beforeEach(() => {
-        ctx.ds.azureMonitorDatasource.getResource = jest.fn().mockResolvedValue(response);
+        ctx.ds.azureResourceGraphDatasource.postResource = jest.fn().mockResolvedValue(response);
       });
 
       it('should return list of Resource Groups', () => {
-        return ctx.ds.getResourceGroups('subscriptionId').then((results: Array<{ text: string; value: string }>) => {
+        return ctx.ds.getResourceGroups('subscriptionId').then((results: RawAzureResourceGroupItem[]) => {
           expect(results.length).toEqual(2);
-          expect(results[0].text).toEqual('grp1');
-          expect(results[0].value).toEqual('grp1');
-          expect(results[1].text).toEqual('grp2');
-          expect(results[1].value).toEqual('grp2');
+          expect(results[0].resourceGroupName).toEqual('grp1');
+          expect(results[0].resourceGroupName).toEqual('grp1');
+          expect(results[1].resourceGroupName).toEqual('grp2');
+          expect(results[1].resourceGroupName).toEqual('grp2');
         });
       });
     });
@@ -709,11 +792,7 @@ describe('AzureMonitorDatasource', () => {
 
       describe('and there are no special cases', () => {
         const response = {
-          value: [
-            {
-              name: 'Failure Anomalies - nodeapp',
-              type: 'microsoft.insights/alertrules',
-            },
+          data: [
             {
               name: resourceGroup,
               type: metricNamespace,
@@ -722,13 +801,7 @@ describe('AzureMonitorDatasource', () => {
         };
 
         beforeEach(() => {
-          ctx.ds.azureMonitorDatasource.getResource = jest.fn().mockImplementation((path: string) => {
-            const basePath = `azuremonitor/subscriptions/${subscription}/resourceGroups`;
-            expect(path).toBe(
-              `${basePath}/${resourceGroup}/resources?api-version=2021-04-01&$filter=resourceType eq '${metricNamespace}'${
-                region ? ` and location eq '${region}'` : ''
-              }`
-            );
+          ctx.ds.azureResourceGraphDatasource.postResource = jest.fn().mockImplementation((path: string) => {
             return Promise.resolve(response);
           });
         });
@@ -736,10 +809,10 @@ describe('AzureMonitorDatasource', () => {
         it('should return list of Resource Names', () => {
           return ctx.ds
             .getResourceNames(subscription, resourceGroup, metricNamespace)
-            .then((results: Array<{ text: string; value: string }>) => {
+            .then((results: RawAzureResourceItem[]) => {
               expect(results.length).toEqual(1);
-              expect(results[0].text).toEqual('nodeapp');
-              expect(results[0].value).toEqual('nodeapp');
+              expect(results[0].name).toEqual('nodeapp');
+              expect(results[0].name).toEqual('nodeapp');
             });
         });
 
@@ -747,10 +820,10 @@ describe('AzureMonitorDatasource', () => {
           metricNamespace = 'microsoft.insights/Components';
           return ctx.ds
             .getResourceNames(subscription, resourceGroup, metricNamespace)
-            .then((results: Array<{ text: string; value: string }>) => {
+            .then((results: RawAzureResourceItem[]) => {
               expect(results.length).toEqual(1);
-              expect(results[0].text).toEqual('nodeapp');
-              expect(results[0].value).toEqual('nodeapp');
+              expect(results[0].name).toEqual('nodeapp');
+              expect(results[0].name).toEqual('nodeapp');
             });
         });
 
@@ -758,58 +831,68 @@ describe('AzureMonitorDatasource', () => {
           region = 'eastus';
           return ctx.ds
             .getResourceNames(subscription, resourceGroup, metricNamespace, region)
-            .then((results: Array<{ text: string; value: string }>) => {
+            .then((results: RawAzureResourceItem[]) => {
               expect(results.length).toEqual(1);
-              expect(results[0].text).toEqual('nodeapp');
-              expect(results[0].value).toEqual('nodeapp');
+              expect(results[0].name).toEqual('nodeapp');
+              expect(results[0].name).toEqual('nodeapp');
             });
         });
 
         it('should return multiple resources from a template variable', () => {
-          replace = (target?: string) => {
+          replace = (
+            target?: string,
+            _scopedVars?: ScopedVars,
+            _format?: string | Function,
+            interpolated?: VariableInterpolation[]
+          ) => {
             if (target?.includes('$reg')) {
+              if (interpolated) {
+                interpolated.push({ value: 'eastus', match: '$reg', variableName: 'reg' });
+              }
               return 'eastus';
             }
+
+            if (target === `$${multiVariable.id}`) {
+              if (interpolated) {
+                interpolated.push({ value: 'foo,bar', match: `$${multiVariable.id}`!, variableName: 'target' });
+              }
+              return 'foo,bar';
+            }
+
+            if (interpolated) {
+              interpolated.push({ value: target ?? '', match: `$${target}`!, variableName: 'target' });
+            }
             return target === `$${multiVariable.id}` ? 'foo,bar' : (target ?? '');
           };
           const ds = new AzureMonitorDatasource(ctx.instanceSettings);
-          //ds.azureMonitorDatasource.templateSrv = tsrv;
-          ds.azureMonitorDatasource.getResource = jest
+          ds.azureResourceGraphDatasource.postResource = jest
             .fn()
-            .mockImplementationOnce((path: string) => {
-              expect(path).toMatch('foo');
-              return Promise.resolve(response);
-            })
-            .mockImplementationOnce((path: string) => {
-              expect(path).toMatch('bar');
-              return Promise.resolve({
-                value: [
+            .mockImplementationOnce(() => Promise.resolve(response))
+            .mockImplementationOnce(() =>
+              Promise.resolve({
+                data: [
                   {
                     name: resourceGroup + '2',
                     type: metricNamespace,
                   },
                 ],
-              });
-            });
+              })
+            );
           return ds
             .getResourceNames(subscription, `$${multiVariable.id}`, metricNamespace)
-            .then((results: Array<{ text: string; value: string }>) => {
+            .then((results: RawAzureResourceItem[]) => {
               expect(results.length).toEqual(2);
-              expect(results[0].text).toEqual('nodeapp');
-              expect(results[0].value).toEqual('nodeapp');
-              expect(results[1].text).toEqual('nodeapp2');
-              expect(results[1].value).toEqual('nodeapp2');
+              expect(results[0].name).toEqual('nodeapp');
+              expect(results[0].name).toEqual('nodeapp');
+              expect(results[1].name).toEqual('nodeapp2');
+              expect(results[1].name).toEqual('nodeapp2');
             });
         });
       });
 
       describe('and the metric definition is blobServices', () => {
         const response = {
-          value: [
-            {
-              name: 'Failure Anomalies - nodeapp',
-              type: 'microsoft.insights/alertrules',
-            },
+          data: [
             {
               name: 'storagetest',
               type: 'microsoft.storage/storageaccounts',
@@ -820,78 +903,32 @@ describe('AzureMonitorDatasource', () => {
         it('should return list of Resource Names', () => {
           metricNamespace = 'microsoft.storage/storageaccounts/blobservices';
           const validMetricNamespace = 'microsoft.storage/storageaccounts';
-          ctx.ds.azureMonitorDatasource.getResource = jest.fn().mockImplementation((path: string) => {
-            const basePath = `azuremonitor/subscriptions/${subscription}/resourceGroups`;
-            expect(path).toBe(
-              basePath +
-                `/${resourceGroup}/resources?api-version=2021-04-01&$filter=resourceType eq '${validMetricNamespace}'`
-            );
-            return Promise.resolve(response);
-          });
+          ctx.ds.azureResourceGraphDatasource.postResource = jest
+            .fn()
+            .mockImplementation(() => Promise.resolve(response));
           return ctx.ds
             .getResourceNames(subscription, resourceGroup, metricNamespace)
-            .then((results: Array<{ text: string; value: string }>) => {
+            .then((results: RawAzureResourceItem[]) => {
               expect(results.length).toEqual(1);
-              expect(results[0].text).toEqual('storagetest/default');
-              expect(results[0].value).toEqual('storagetest/default');
-              expect(ctx.ds.azureMonitorDatasource.getResource).toHaveBeenCalledWith(
-                `azuremonitor/subscriptions/${subscription}/resourceGroups/${resourceGroup}/resources?api-version=2021-04-01&$filter=resourceType eq '${validMetricNamespace}'`
+              expect(results[0].name).toEqual('storagetest');
+              expect(results[0].name).toEqual('storagetest');
+              expect(ctx.ds.azureResourceGraphDatasource.postResource).toHaveBeenCalledWith(
+                'resourcegraph/providers/Microsoft.ResourceGraph/resources?api-version=2021-03-01',
+                {
+                  options: { resultFormat: 'objectArray' },
+                  query: `resources
+        | where id hasprefix \"/subscriptions/${subscription}/resourceGroups/${resourceGroup}/\"
+        | where type == '${validMetricNamespace}'
+        | order by tolower(name) asc`,
+                }
               );
             });
         });
       });
 
-      describe('and there are several pages', () => {
-        const skipToken = 'token';
-        const response1 = {
-          value: [
-            {
-              name: `${resourceGroup}1`,
-              type: metricNamespace,
-            },
-          ],
-          nextLink: `https://management.azure.com/resourceuri?$skiptoken=${skipToken}`,
-        };
-        const response2 = {
-          value: [
-            {
-              name: `${resourceGroup}2`,
-              type: metricNamespace,
-            },
-          ],
-        };
-
-        beforeEach(() => {
-          const fn = jest.fn();
-          ctx.ds.azureMonitorDatasource.getResource = fn;
-          const basePath = `azuremonitor/subscriptions/${subscription}/resourceGroups`;
-          const expectedPath = `${basePath}/${resourceGroup}/resources?api-version=2021-04-01&$filter=resourceType eq '${metricNamespace}'`;
-          // first page
-          fn.mockImplementationOnce((path: string) => {
-            expect(path).toBe(expectedPath);
-            return Promise.resolve(response1);
-          });
-          // second page
-          fn.mockImplementationOnce((path: string) => {
-            expect(path).toBe(`${expectedPath}&$skiptoken=${skipToken}`);
-            return Promise.resolve(response2);
-          });
-        });
-
-        it('should return list of Resource Names', () => {
-          return ctx.ds
-            .getResourceNames(subscription, resourceGroup, metricNamespace)
-            .then((results: Array<{ text: string; value: string }>) => {
-              expect(results.length).toEqual(2);
-              expect(results[0].value).toEqual(`${resourceGroup}1`);
-              expect(results[1].value).toEqual(`${resourceGroup}2`);
-            });
-        });
-      });
-
       describe('without a resource group or a metric definition', () => {
         const response = {
-          value: [
+          data: [
             {
               name: 'Failure Anomalies - nodeapp',
               type: 'microsoft.insights/alertrules',
@@ -904,15 +941,13 @@ describe('AzureMonitorDatasource', () => {
         };
 
         beforeEach(() => {
-          ctx.ds.azureMonitorDatasource.getResource = jest.fn().mockImplementation((path: string) => {
-            const basePath = `azuremonitor/subscriptions/${subscription}/resources?api-version=2021-04-01`;
-            expect(path).toBe(basePath);
+          ctx.ds.azureResourceGraphDatasource.postResource = jest.fn().mockImplementation((path: string) => {
             return Promise.resolve(response);
           });
         });
 
         it('should return list of Resource Names', () => {
-          return ctx.ds.getResourceNames(subscription).then((results: Array<{ text: string; value: string }>) => {
+          return ctx.ds.getResourceNames(subscription).then((results: RawAzureResourceItem[]) => {
             expect(results.length).toEqual(2);
           });
         });
