@@ -3,7 +3,7 @@ import * as React from 'react';
 import { useDebounce } from 'react-use';
 
 import { QueryEditorProps, getDefaultTimeRange, toOption } from '@grafana/data';
-import { EditorField, EditorRows } from '@grafana/experimental';
+import { EditorField, EditorRows } from '@grafana/plugin-ui';
 import { Input } from '@grafana/ui';
 
 import CloudMonitoringDatasource from '../datasource';
