@@ -1,14 +1,13 @@
 import { css } from '@emotion/css';
-import React from 'react';
+import * as React from 'react';
 
 import { CoreApp, GrafanaTheme2, SelectableValue } from '@grafana/data';
-import { config } from '@grafana/runtime';
 import { useStyles2, RadioButtonGroup, MultiSelect, Input } from '@grafana/ui';
 
-import { QueryOptionGroup } from '../../prometheus/querybuilder/shared/QueryOptionGroup';
 import { Query } from '../types';
 
 import { EditorField } from './EditorField';
+import { QueryOptionGroup } from './QueryOptionGroup';
 import { Stack } from './Stack';
 
 export interface Props {
@@ -48,6 +47,12 @@ export function QueryOptions({ query, onQueryChange, app, labels }: Props) {
   if (query.groupBy?.length) {
     collapsedInfo.push(`Group by: ${query.groupBy.join(', ')}`);
   }
+  if (query.limit) {
+    collapsedInfo.push(`Limit: ${query.limit}`);
+  }
+  if (query.spanSelector?.length) {
+    collapsedInfo.push(`Span ID: ${query.spanSelector.join(', ')}`);
+  }
   if (query.maxNodes) {
     collapsedInfo.push(`Max nodes: ${query.maxNodes}`);
   }
@@ -84,21 +89,39 @@ export function QueryOptions({ query, onQueryChange, app, labels }: Props) {
               }}
             />
           </EditorField>
-          {config.featureToggles.traceToProfiles && (
-            <EditorField label={'Span ID'} tooltip={<>Sets the span ID from which to search for profiles.</>}>
-              <Input
-                value={query.spanSelector || ['']}
-                type="string"
-                placeholder="64f170a95f537095"
-                onChange={(event: React.SyntheticEvent<HTMLInputElement>) => {
-                  onQueryChange({
-                    ...query,
-                    spanSelector: event.currentTarget.value !== '' ? [event.currentTarget.value] : [],
-                  });
-                }}
-              />
-            </EditorField>
-          )}
+          <EditorField
+            label={'Limit'}
+            tooltip={
+              <>
+                When &quot;Group by&quot; is set, limits the maximum number of series to return. Does not apply to
+                profile query.
+              </>
+            }
+          >
+            <Input
+              value={query.limit || ''}
+              type="number"
+              placeholder="0"
+              onChange={(event: React.SyntheticEvent<HTMLInputElement>) => {
+                let newValue = parseInt(event.currentTarget.value, 10);
+                newValue = isNaN(newValue) ? 0 : newValue;
+                onQueryChange({ ...query, limit: newValue });
+              }}
+            />
+          </EditorField>
+          <EditorField label={'Span ID'} tooltip={<>Sets the span ID from which to search for profiles.</>}>
+            <Input
+              value={query.spanSelector || ['']}
+              type="string"
+              placeholder="64f170a95f537095"
+              onChange={(event: React.SyntheticEvent<HTMLInputElement>) => {
+                onQueryChange({
+                  ...query,
+                  spanSelector: event.currentTarget.value !== '' ? [event.currentTarget.value] : [],
+                });
+              }}
+            />
+          </EditorField>
           <EditorField label={'Max Nodes'} tooltip={<>Sets the maximum number of nodes to return in the flamegraph.</>}>
             <Input
               value={query.maxNodes || ''}
