@@ -1,7 +1,13 @@
 import { css } from '@emotion/css';
-import React from 'react';
 
 import { DataSourcePluginOptionsEditorProps, GrafanaTheme2 } from '@grafana/data';
+import {
+  NodeGraphSection,
+  SpanBarSection,
+  TraceToLogsSection,
+  TraceToMetricsSection,
+  TraceToProfilesSection,
+} from '@grafana/o11y-ds-frontend';
 import {
   AdvancedHttpSettings,
   Auth,
@@ -11,25 +17,19 @@ import {
   ConnectionSettings,
   convertLegacyAuthProps,
   DataSourceDescription,
-} from '@grafana/experimental';
-import {
-  NodeGraphSection,
-  SpanBarSection,
-  TraceToLogsSection,
-  TraceToMetricsSection,
-  TraceToProfilesSection,
-} from '@grafana/o11y-ds-frontend';
+} from '@grafana/plugin-ui';
 import { config } from '@grafana/runtime';
 import { SecureSocksProxySettings, useStyles2, Divider, Stack } from '@grafana/ui';
 
-import { LokiSearchSettings } from './LokiSearchSettings';
 import { QuerySettings } from './QuerySettings';
 import { ServiceGraphSettings } from './ServiceGraphSettings';
+import { StreamingSection } from './StreamingSection';
+import { TagLimitSection } from './TagLimitSettings';
 import { TraceQLSearchSettings } from './TraceQLSearchSettings';
 
-export type Props = DataSourcePluginOptionsEditorProps;
+export type ConfigEditorProps = DataSourcePluginOptionsEditorProps;
 
-export const ConfigEditor = ({ options, onOptionsChange }: Props) => {
+const ConfigEditor = ({ options, onOptionsChange }: ConfigEditorProps) => {
   const styles = useStyles2(getStyles);
 
   return (
@@ -50,17 +50,16 @@ export const ConfigEditor = ({ options, onOptionsChange }: Props) => {
           onChange: onOptionsChange,
         })}
       />
-
       <Divider spacing={4} />
+
+      <StreamingSection options={options} onOptionsChange={onOptionsChange} />
+      <Divider spacing={4} />
+
       <TraceToLogsSection options={options} onOptionsChange={onOptionsChange} />
-
       <Divider spacing={4} />
-      {config.featureToggles.traceToMetrics ? (
-        <>
-          <TraceToMetricsSection options={options} onOptionsChange={onOptionsChange} />
-          <Divider spacing={4} />
-        </>
-      ) : null}
+
+      <TraceToMetricsSection options={options} onOptionsChange={onOptionsChange} />
+      <Divider spacing={4} />
 
       <TraceToProfilesSection options={options} onOptionsChange={onOptionsChange} />
       <Divider spacing={4} />
@@ -75,9 +74,7 @@ export const ConfigEditor = ({ options, onOptionsChange }: Props) => {
           <AdvancedHttpSettings config={options} onChange={onOptionsChange} />
 
           {config.secureSocksDSProxyEnabled && (
-            <>
-              <SecureSocksProxySettings options={options} onOptionsChange={onOptionsChange} />
-            </>
+            <SecureSocksProxySettings options={options} onOptionsChange={onOptionsChange} />
           )}
 
           <ConfigSubSection
@@ -108,19 +105,6 @@ export const ConfigEditor = ({ options, onOptionsChange }: Props) => {
             <TraceQLSearchSettings options={options} onOptionsChange={onOptionsChange} />
           </ConfigSubSection>
 
-          <ConfigSubSection
-            title="Loki search"
-            description={
-              <ConfigDescriptionLink
-                description="Select a Loki data source to search for traces. Derived fields must be configured in the Loki data source."
-                suffix="tempo/configure-tempo-data-source/#loki-search"
-                feature="Loki search"
-              />
-            }
-          >
-            <LokiSearchSettings options={options} onOptionsChange={onOptionsChange} />
-          </ConfigSubSection>
-
           <ConfigSubSection
             title="TraceID query"
             description={
@@ -135,6 +119,8 @@ export const ConfigEditor = ({ options, onOptionsChange }: Props) => {
           </ConfigSubSection>
 
           <SpanBarSection options={options} onOptionsChange={onOptionsChange} />
+
+          <TagLimitSection options={options} onOptionsChange={onOptionsChange} />
         </Stack>
       </ConfigSection>
     </div>
@@ -143,8 +129,9 @@ export const ConfigEditor = ({ options, onOptionsChange }: Props) => {
 
 const getStyles = (theme: GrafanaTheme2) => ({
   container: css({
-    label: 'container',
     marginBottom: theme.spacing(2),
     maxWidth: '900px',
   }),
 });
+
+export default ConfigEditor;
