@@ -1,5 +1,5 @@
 import { css } from '@emotion/css';
-import React, { useEffect, useRef, useState } from 'react';
+import { useEffect, useRef, useState } from 'react';
 
 import { GrafanaTheme2 } from '@grafana/data';
 import { TemporaryAlert } from '@grafana/o11y-ds-frontend';
@@ -9,7 +9,7 @@ import { CodeEditor, Monaco, monacoTypes, useTheme2 } from '@grafana/ui';
 import { TempoDatasource } from '../datasource';
 import { TempoQuery } from '../types';
 
-import { CompletionProvider, CompletionType } from './autocomplete';
+import { CompletionProvider, CompletionItemType } from './autocomplete';
 import { getErrorNodes, setMarkers } from './highlighting';
 import { languageDefinition } from './traceql';
 
@@ -23,7 +23,7 @@ interface Props {
 }
 
 export function TraceQLEditor(props: Props) {
-  const [alertText, setAlertText] = useState('');
+  const [alertText, setAlertText] = useState<string>();
 
   const { query, onChange, onRunQuery, placeholder } = props;
   const setupAutocompleteFn = useAutocomplete(props.datasource, setAlertText);
@@ -109,14 +109,14 @@ export function TraceQLEditor(props: Props) {
               errorNodes.filter((errorNode) => !(errorNode.from <= cursorPosition && cursorPosition <= errorNode.to))
             );
 
-            // Later on, show all errors
+            // Show all errors after a short delay, to avoid flickering
             errorTimeoutId.current = window.setTimeout(() => {
               setMarkers(monaco, model, errorNodes);
             }, 500);
           });
         }}
       />
-      {alertText && <TemporaryAlert severity={'error'} text={alertText} />}
+      {alertText && <TemporaryAlert severity="error" text={alertText} />}
     </>
   );
 }
@@ -126,7 +126,7 @@ function setupPlaceholder(editor: monacoTypes.editor.IStandaloneCodeEditor, mona
     {
       range: new monaco.Range(1, 1, 1, 1),
       options: {
-        className: styles.placeholder, // The placeholder text is in styles.placeholder
+        className: styles.placeholder,
         isWholeLine: true,
       },
     },
@@ -163,7 +163,7 @@ function setupActions(editor: monacoTypes.editor.IStandaloneCodeEditor, monaco:
 }
 
 function setupRegisterInteractionCommand(editor: monacoTypes.editor.IStandaloneCodeEditor): string | null {
-  return editor.addCommand(0, function (_, label, type: CompletionType) {
+  return editor.addCommand(0, function (_, label, type: CompletionItemType) {
     const properties: Record<string, unknown> = { datasourceType: 'tempo', type };
     // Filter out the label for TAG_VALUE completions to avoid potentially exposing sensitive data
     if (type !== 'TAG_VALUE') {
@@ -193,23 +193,23 @@ function setupAutoSize(editor: monacoTypes.editor.IStandaloneCodeEditor) {
  * @param datasource the Tempo datasource instance
  * @param setAlertText setter for alert's text
  */
-function useAutocomplete(datasource: TempoDatasource, setAlertText: (text: string) => void) {
+function useAutocomplete(datasource: TempoDatasource, setAlertText: (text?: string) => void) {
   // We need the provider ref so we can pass it the label/values data later. This is because we run the call for the
   // values here but there is additional setup needed for the provider later on. We could run the getSeries() in the
   // returned function but that is run after the monaco is mounted so would delay the request a bit when it does not
   // need to.
   const providerRef = useRef<CompletionProvider>(
-    new CompletionProvider({ languageProvider: datasource.languageProvider })
+    new CompletionProvider({ languageProvider: datasource.languageProvider, setAlertText })
   );
 
   useEffect(() => {
     const fetchTags = async () => {
       try {
         await datasource.languageProvider.start();
+        setAlertText(undefined);
       } catch (error) {
         if (error instanceof Error) {
-          console.error(error);
-          setAlertText(error.message);
+          setAlertText(`Error: ${error.message}`);
         }
       }
     };
