@@ -1,4 +1,5 @@
 import { Fill, RegularShape, Stroke, Circle, Style, Icon, Text } from 'ol/style';
+import { LiteralStyle } from 'ol/style/literal';
 import tinycolor from 'tinycolor2';
 
 import { Registry, RegistryItem, textUtil } from '@grafana/data';
@@ -31,6 +32,12 @@ const MarkerShapePath = {
   x: 'img/icons/marker/x-mark.svg',
 };
 
+const WebGLRegularShapes: Record<string, string> = {
+  circle: 'img/icons/marker/circle.svg',
+  square: 'img/icons/marker/square.svg',
+  triangle: 'img/icons/marker/triangle.svg',
+};
+
 export function getFillColor(cfg: StyleConfigValues) {
   const opacity = cfg.opacity == null ? 0.8 : cfg.opacity;
   if (opacity === 1) {
@@ -251,7 +258,7 @@ const makers: SymbolMaker[] = [
   },
 ];
 
-async function prepareSVG(url: string, size?: number): Promise<string> {
+async function prepareSVG(url: string, size?: number, backgroundOpacity?: number): Promise<string> {
   return fetch(url, { method: 'GET' })
     .then((res) => {
       return res.text();
@@ -274,6 +281,23 @@ async function prepareSVG(url: string, size?: number): Promise<string> {
       svg.setAttribute('fill', '#fff');
       svg.setAttribute('width', `${width}px`);
       svg.setAttribute('height', `${height}px`);
+
+      // add a mostly transparent circle behind the icon for webGL hit detection
+      // TODO open layers discards fully transparent elements for hit detection
+      if (backgroundOpacity) {
+        const viewBox = svg.getAttribute('viewBox')?.split(' ') ?? [0, 0, width, height];
+        const viewCenterX = Number(viewBox[2]) / 2;
+        const viewCenterY = Number(viewBox[3]) / 2;
+        const circleElement = doc.createElementNS('http://www.w3.org/2000/svg', 'circle');
+        circleElement.setAttribute('cx', viewCenterX.toString());
+        circleElement.setAttribute('cy', viewCenterY.toString());
+        circleElement.setAttribute('fill', 'none');
+        circleElement.setAttribute('r', (viewCenterX / 2).toString());
+        circleElement.setAttribute('stroke', `rgba(255,255,255,${backgroundOpacity})`);
+        circleElement.setAttribute('stroke-width', viewCenterX.toString());
+        svg.prepend(circleElement);
+      }
+
       const svgString = new XMLSerializer().serializeToString(svg);
       const svgURI = encodeURIComponent(svgString);
       return `data:image/svg+xml,${svgURI}`;
@@ -295,6 +319,36 @@ export function getMarkerAsPath(shape?: string): string | undefined {
   return undefined;
 }
 
+// Returns literal style for WebGL markers
+export async function getWebGLStyle(symbol?: string, opacity?: number): Promise<LiteralStyle> {
+  // style expressions
+  const symbolStyle: LiteralStyle = {
+    symbol: {
+      symbolType: 'circle',
+      size: ['get', 'size', 'number'],
+      color: ['color', ['get', 'red'], ['get', 'green'], ['get', 'blue']],
+      offset: ['array', ['get', 'offsetX'], ['get', 'offsetY']],
+      rotation: ['get', 'rotation', 'number'],
+      opacity: ['get', 'opacity', 'number'],
+    },
+  };
+  // set symbolType and src if a symbol is provided
+  if (symbol && symbolStyle.symbol) {
+    const imageString = 'image';
+    const symbolType = Object.keys(WebGLRegularShapes).find((key) => WebGLRegularShapes[key] === symbol) ?? imageString;
+    symbolStyle.symbol = { ...symbolStyle.symbol, symbolType };
+    if (symbolType === imageString) {
+      const backgroundOpacity = opacity === 0 ? 0 : 0.1 / (opacity ?? 1);
+      symbolStyle.symbol = {
+        ...symbolStyle.symbol,
+        src: await prepareSVG(getPublicOrAbsoluteUrl(symbol), undefined, backgroundOpacity),
+      };
+    }
+  }
+
+  return symbolStyle;
+}
+
 // Will prepare symbols as necessary
 export async function getMarkerMaker(symbol?: string, hasTextLabel?: boolean): Promise<StyleMaker> {
   if (!symbol) {
